@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
+#define QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
+
 #define QT_FEATURE_webengine_embedded_build -1
 
 #define QT_FEATURE_webengine_system_alsa -1
@@ -32,3 +35,5 @@
 
 #define QT_FEATURE_webengine_arm64_udot_support -1
 
+
+#endif // QT_FEATURES_WebEngineCore_src_core_api_qtwebenginecore_config_p_h_H
